@@ -2,7 +2,7 @@
 import logging
 from threading import Timer as _Timer, RLock
 
-logger = logging.getLogger('vindauga.types.timer')
+logger = logging.getLogger(__name__)
 
 
 class Timer:
@@ -35,6 +35,7 @@ class Timer:
     def expire(self):
         with self.__lock:
             self._expired = True
+            self._timer = None
 
     def isRunning(self) -> bool:
         with self.__lock:
