@@ -1,15 +1,20 @@
 # -*- coding: utf-8 -*-
 import logging
+from typing import Optional
 
 from vindauga.constants.event_codes import evBroadcast
 from vindauga.constants.command_codes import cmScrollBarChanged, cmReceivedFocus
 from vindauga.constants.grow_flags import gfGrowHiX, gfGrowHiY
 from vindauga.constants.state_flags import sfSelected, sfActive
+from vindauga.constants.option_flags import ofSelectable
 from vindauga.types.group import Group
 from vindauga.types.point import Point
 from vindauga.types.view import View
 
 from .background import Background
+from .scroll_bar import ScrollBar
+from ..events.event import Event
+from ..types.rect import Rect
 
 logger = logging.getLogger(__name__)
 sbHorizontalBar = 1
@@ -18,7 +23,11 @@ sbVerticalBar = 2
 
 class ScrollGroup(Group):
 
-    def __init__(self, bounds, hScrollBar, vScrollBar):
+    class ScrollInfo:
+        delta: Point
+        ignore: View
+
+    def __init__(self, bounds: Rect, hScrollBar: Optional[ScrollBar], vScrollBar: Optional[ScrollBar]):
         super().__init__(bounds)
         self.hScrollBar = hScrollBar
         self.vScrollBar = vScrollBar
@@ -33,16 +42,16 @@ class ScrollGroup(Group):
             self.insert(self.background)
 
     @staticmethod
-    def initBackground(r):
+    def initBackground(r: Rect) -> Background:
         return Background(r, ' ')
 
     @staticmethod
-    def doScroll(view, info):
+    def doScroll(view: View, info: ScrollInfo):
         if view is not info.ignore:
             dest = view.origin + info.delta
             view.moveTo(dest.x, dest.y)
 
-    def changeBounds(self, bounds):
+    def changeBounds(self, bounds: Rect):
         self.lock()
         try:
             super().changeBounds(bounds)
@@ -51,7 +60,7 @@ class ScrollGroup(Group):
             self.unlock()
         self.drawView()
 
-    def handleEvent(self, event):
+    def handleEvent(self, event: Event):
         super().handleEvent(event)
         if event.what == evBroadcast:
             if (event.message.command == cmScrollBarChanged and
@@ -61,10 +70,6 @@ class ScrollGroup(Group):
                   self.firstThat(lambda view, args: view is args, event.message.infoPtr)):
                 self.focusSubView(event.message.infoPtr)
 
-    class ScrollInfo:
-        delta: Point
-        ignore: View
-
     def scrollDraw(self):
         d = Point(0, 0)
         d.x = self.hScrollBar.value if self.hScrollBar else 0
@@ -82,7 +87,7 @@ class ScrollGroup(Group):
                 self.unlock()
             self.drawView()
 
-    def scrollTo(self, x, y):
+    def scrollTo(self, x: int, y: int):
         self.lock()
         try:
             if self.hScrollBar and x != self.hScrollBar.value:
@@ -93,7 +98,7 @@ class ScrollGroup(Group):
             self.unlock()
         self.scrollDraw()
 
-    def setLimit(self, x, y):
+    def setLimit(self, x: int, y: int):
         self.limit.x = x
         self.limit.y = y
 
@@ -107,7 +112,7 @@ class ScrollGroup(Group):
             self.unlock()
         self.scrollDraw()
 
-    def setState(self, state, enable):
+    def setState(self, state: int, enable: bool):
         super().setState(state, enable)
         if state & (sfActive | sfSelected):
             if self.hScrollBar:
@@ -121,7 +126,7 @@ class ScrollGroup(Group):
                 else:
                     self.vScrollBar.hide()
 
-    def focusSubView(self, view):
+    def focusSubView(self, view: View):
         rView = view.getBounds()
         r = self.getExtent()
         r.intersect(rView)
@@ -139,17 +144,30 @@ class ScrollGroup(Group):
                 dy = self.delta.y + view.origin.y + view.size.y - self.size.y
             self.scrollTo(dx, dy)
 
-    def selectNext(self, forward):
+    def selectNext(self, forward: bool):
         # This logic should probably live in group so that groups of groups work.
+        def selectableView(v: View) -> bool:
+            logger.info('selectable(%s) - %s', v, v.options & ofSelectable)
+            return bool(v.options & ofSelectable)
+
         if self.current and isinstance(self.current, Group):
             # If current child is itself a group then focus its next
             child = self.current.current
-            first = self.current.first
-            last = self.current.last
+            last = self.current.firstThat(selectableView)  # self.current.first
+            first = self.current.lastThat(selectableView)  # self.current.last
             self.current.selectNext(forward)
             # If we weren't on the boundary child then don't focus the next group item
-            if (child and ((child is not first and not forward) or
-                           (child is not last and forward))):
+            if child not in {first, last}:
+                return
+            if not ((child is first and forward) or (child is last and not forward)):
                 return
             # Fall through. We're on the edge and rather than go in a circle, focus the next item in the scroll group
         super().selectNext(forward)
+        # We moved groups make sure we focus the first or last item.
+        if self.current and isinstance(self.current, Group):
+            first = self.current.firstThat(selectableView)  # self.current.first
+            last = self.current.lastThat(selectableView)  # self.current.last
+            if forward:
+                first.select()
+            else:
+                last.select()
